@@ -45,8 +45,10 @@ class TestContainer(unittest.TestCase):
 
         c.add_factory(foobar, 'foobar', True)
 
+        self.assertFalse(c.is_cached('foobar'))
         dict1 = c('foobar')
         dict2 = c('foobar')
+        self.assertTrue(c.is_cached('foobar'))
 
         assert isinstance(dict1, dict)
         assert isinstance(dict2, dict)
